SnapServer

Struct SnapServer 

pub struct SnapServer { /* private fields */ }
The embeddable Snapcast server.

Implementations

Source

impl SnapServer

pub fn new( config: ServerConfig, ) -> (Self, Receiver<ServerEvent>, Sender<AudioFrame>)

Create a new server. Returns the server, event receiver, and audio input sender.

The audio_tx sender allows the embedding app to push PCM audio directly into the server as an alternative to pipe/file/process stream readers.

pub fn set_manager(&mut self, manager: StreamManager)

Set the stream manager (configured by the binary with stream readers).

pub fn command_sender(&self) -> Sender<ServerCommand>

Get a cloneable command sender.

pub fn config(&self) -> &ServerConfig

Access the server configuration.

pub async fn run(&mut self) -> Result<()>

Run the server. Blocks until stopped or a fatal error occurs.