pub struct SnapServer { /* private fields */ }Expand description
The embeddable Snapcast server.
Implementations
Sourceimpl SnapServer
impl SnapServer
Sourcepub fn new(
config: ServerConfig,
) -> (Self, Receiver<ServerEvent>, Sender<AudioFrame>)
pub fn new( config: ServerConfig, ) -> (Self, Receiver<ServerEvent>, Sender<AudioFrame>)
Create a new server. Returns the server, event receiver, and audio input sender.
The audio_tx sender allows the embedding app to push PCM audio directly
into the server as an alternative to pipe/file/process stream readers.
Sourcepub fn set_manager(&mut self, manager: StreamManager)
pub fn set_manager(&mut self, manager: StreamManager)
Set the stream manager (configured by the binary with stream readers).
Sourcepub fn command_sender(&self) -> Sender<ServerCommand>
pub fn command_sender(&self) -> Sender<ServerCommand>
Get a cloneable command sender.
Sourcepub fn config(&self) -> &ServerConfig
pub fn config(&self) -> &ServerConfig
Access the server configuration.